pecos.tools.threshold\_tools
============================

.. automodule:: pecos.tools.threshold_tools

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      codecapacity_logical_rate
      codecapacity_logical_rate2
      codecapacity_logical_rate3
      threshold_code_capacity
      threshold_code_capacity_calc
   
   

   
   
   

   
   
   



